@@ -12,6 +12,7 @@ from strenum import StrEnum
 
 class ConfigCategory(StrEnum):
     admin=auto()
+    branding=auto()
     general=auto()
     proxies=auto()
     domain_fronting=auto()
@@ -27,6 +28,7 @@ class ConfigCategory(StrEnum):
 
 class ConfigEnum(StrEnum):
     lang = auto()
+    admin_lang = auto()
     admin_secret = auto()
     tls_ports = auto()
     http_ports = auto()
@@ -48,6 +50,7 @@ class ConfigEnum(StrEnum):
     telegram_enable = auto()
     # telegram_secret=auto()
     telegram_adtag = auto()
+    telegram_lib = auto()
     telegram_fakedomain = auto()
 
     v2ray_enable = auto()
@@ -74,15 +77,23 @@ class ConfigEnum(StrEnum):
     domain_fronting_tls_enable = auto()
 
     db_version = auto()
+
+    branding_title=auto()
+    branding_site=auto()
+    branding_freetext=auto()
     not_found=auto()
     @classmethod
     def _missing_(cls, value):
       return cls.not_found #"key not found"
     def info(self):
         map = {
+            self.branding_title:{'category': ConfigCategory.branding},
+            self.branding_site:{'category': ConfigCategory.branding},
+            self.branding_freetext:{'category': ConfigCategory.branding},
             self.not_found:{'category': ConfigCategory.hidden},
-            self.lang: {'category': ConfigCategory.general},
             self.admin_secret: {'category': ConfigCategory.admin},
+            self.lang: {'category': ConfigCategory.branding},
+            self.admin_lang: {'category': ConfigCategory.admin},
             self.tls_ports: {'category': ConfigCategory.tls},
             self.http_ports: {'category': ConfigCategory.http},
             self.kcp_ports: {'category': ConfigCategory.kcp},
@@ -105,6 +116,7 @@ class ConfigEnum(StrEnum):
             # telegram_secret:{'category':'general'},
             self.telegram_adtag: {'category': ConfigCategory.telegram},
             self.telegram_fakedomain: {'category': ConfigCategory.telegram},
+            self.telegram_lib: {'category': ConfigCategory.telegram},
 
             self.v2ray_enable: {'category': ConfigCategory.proxies,'type':bool},
 
@@ -139,9 +151,9 @@ class ConfigEnum(StrEnum):
         return info['type'] if 'type' in info else str
 
 
-class DomainType(enum.Enum):
-    direct = "direct"
-    cdn = "cdn"
+class DomainType(StrEnum):
+    direct = auto()
+    cdn = auto()
     # fake_cdn = "fake_cdn"
     # telegram_faketls = "telegram_faketls"
     # ss_faketls = "ss_faketls"
@@ -172,10 +184,12 @@ class User(db.Model, SerializerMixin):
     name = db.Column(db.String(512), nullable=False)
     # monthly_usage_limit=db.Column(db.BigInteger,default=100,nullable=False)
     # current_usage=db.Column(db.BigInteger,default=0,nullable=False)
-    monthly_usage_limit_GB = db.Column(db.Numeric(
+    usage_limit_GB = db.Column(db.Numeric(
         6, 9, asdecimal=False), default=1000, nullable=False)
     current_usage_GB = db.Column(db.Numeric(
         6, 9, asdecimal=False), default=0, nullable=False)
+    
+    monthly=db.Column(db.Boolean,default=False)
 
     expiry_time = db.Column(
         db.Date, default=datetime.date.today() + relativedelta.relativedelta(months=6))
@@ -186,14 +200,12 @@ class BoolConfig(db.Model, SerializerMixin):
     # category = db.Column(db.String(128), primary_key=True)
     key = db.Column(db.Enum(ConfigEnum), primary_key=True)
     value = db.Column(db.Boolean)
-    description = db.Column(db.String(512))
 
 
 class StrConfig(db.Model, SerializerMixin):
     # category = db.Column(db.String(128), primary_key=True)
     key = db.Column(db.Enum(ConfigEnum), primary_key=True,   default=ConfigEnum.admin_secret)
-    value = db.Column(db.String(512))
-    description = db.Column(db.String(512))
+    value = db.Column(db.String(2048))
 
 
 def hdomains(mode):
