@@ -1,4 +1,5 @@
 #!/usr/bin/env python3
+import pprint
 from flask_babelex import gettext as _
 import pathlib
 from hiddifypanel.models import  User,Domain,DomainType,StrConfig,ConfigEnum,hconfig
@@ -9,11 +10,11 @@ import json
 import urllib.request
 import subprocess
 import re
-
+from hiddifypanel.panel import hiddify
 from flask import current_app,render_template,request,Response,Markup,url_for
+from hiddifypanel.panel.hiddify import flash
 
-
-from flask_classful import FlaskView
+from flask_classful import FlaskView,route
 
 class Actions(FlaskView):
 
@@ -21,12 +22,21 @@ class Actions(FlaskView):
         return render_template('index.html')
     
     def reverselog(self,logfile):
+        if logfile==None:return self.viewlogs()
         config_dir=current_app.config.HIDDIFY_CONFIG_PATH
+        
         with open(f'{config_dir}/log/system/{logfile}') as f:
             lines=[line for line in f]
-            resp= Response("".join(lines[::-1]))
-            resp.mimetype="text/plain"
-            return resp
+            logs="".join(lines[::-1])
+        # resp= Response()
+        # resp.mimetype="text/plain"
+        out=f'<pre style="background-color:black; color:white;padding:10px">{logs}</pre>'
+        if "----Finished!---" in out:
+            out=f"<a href='#' target='_blank'><div style='background-color:#b1eab1; padding: 10px;border: solid;'>Finished! For scrolling the log click here.</div></a>{out}"
+
+
+            
+        return out
             
             
 
@@ -34,20 +44,25 @@ class Actions(FlaskView):
     def viewlogs(self):
         config_dir=current_app.config.HIDDIFY_CONFIG_PATH
         res=[]
-        for filename in os.listdir(f'{config_dir}/log/system/'):
+        for filename in sorted(os.listdir(f'{config_dir}/log/system/')):
             res.append(f"<a href='{url_for('admin.Actions:reverselog',logfile=filename)}'>{filename}</a>") 
         return Markup("<br>".join(res))
-    
+        
+    @route('apply_configs', methods=['POST'])
     def apply_configs(self):
         return self.reinstall(False)
 
-    
+    @route('reset', methods=['POST'])
     def reset(self):
-        # subprocess.Popen(f"reboot",start_new_session=True)
-        return self.status()
+        status=self.status()
+        flash(_("rebooting system may takes time please wait"),'info')
+        subprocess.Popen(f"reboot",start_new_session=True)
+        return status
     
+    @route('reinstall', methods=['POST'])
     def reinstall(self,complete_install=True):
         config=current_app.config
+        hiddify.add_temporary_access()
         file="install.sh" if complete_install else "apply_configs.sh"
         try:
             server_ip=urllib.request.urlopen('https://v4.ident.me/').read().decode('utf8')
@@ -57,27 +72,32 @@ class Actions(FlaskView):
         # subprocess.Popen(f"{config_dir}/update.sh",env=my_env,cwd=f"{config_dir}")
         # os.system(f'cd {config_dir};{env} ./install.sh &')
         # rc = subprocess.call(f"cd {config_dir};./{file} & disown",shell=True)
-        subprocess.Popen(f"{config.HIDDIFY_CONFIG_PATH}/{file}",cwd=f"{config.HIDDIFY_CONFIG_PATH}",start_new_session=True)
+        
         admin_secret=hconfig(ConfigEnum.admin_secret)
         proxy_path=hconfig(ConfigEnum.proxy_path)
         admin_links=f"<h5 >{_('Admin Links')}</h5><ul>"
-        admin_links+=f"<li>{_('Not Secure')}: <a class='badge ltr share-link' href='http://{server_ip}/{proxy_path}/{admin_secret}/'>http://{server_ip}/{proxy_path}/{admin_secret}/admin</a></li>"
+        admin_links+=f"<li>{_('Not Secure')}: <a class='badge ltr share-link' href='http://{server_ip}/{proxy_path}/{admin_secret}/admin/'>http://{server_ip}/{proxy_path}/{admin_secret}/admin/</a></li>"
         domains=[d.domain for d in Domain.query.all()]
         # domains=[*domains,f'{server_ip}.sslip.io']
         for d in domains:
-                admin_links+=f"<li><a class='badge ltr  share-link' href='https://{d}/{proxy_path}/{admin_secret}/'>https://{d}/{proxy_path}/{admin_secret}/admin</a></li>"
+                link=f'https://{d}/{proxy_path}/{admin_secret}/admin/'
+                admin_links+=f"<li><a class='badge ltr  share-link' href='{link}'>{link}</a></li>"
 
-        return render_template("result.html",
+        resp= render_template("result.html",
                             out_type="success",
                             out_msg=_("Success! Please wait around 4 minutes to make sure everything is updated. During this time, please save your proxy links which are:")+
                                     admin_links,
-                            log_path=f"https://{domains[0]}/{proxy_path}/{admin_secret}/actions/reverselog/0-install.log"
+                            log_path=f"https://{domains[0]}/{proxy_path}/{admin_secret}/admin/actions/reverselog/0-install.log/"
                             
         )
 
+        subprocess.Popen(f"{config.HIDDIFY_CONFIG_PATH}/{file}",cwd=f"{config.HIDDIFY_CONFIG_PATH}",start_new_session=True)
+        return resp
+
 
     
     def status(self):
+        hiddify.add_temporary_access()
         config=current_app.config
         # configs=read_configs()
         # subprocess.Popen(f"{config_dir}/update.sh",env=my_env,cwd=f"{config_dir}")
@@ -96,8 +116,9 @@ class Actions(FlaskView):
 
 
 
-    
+    @route('update', methods=['POST'])
     def update(self):
+        hiddify.add_temporary_access()
         config=current_app.config
         cwd = os.getcwd()
         
@@ -106,6 +127,7 @@ class Actions(FlaskView):
         # rc = subprocess.call(f"cd {config_dir};./update.sh & disown",shell=True)
         # os.system(f'cd {config_dir};./update.sh &')
 
+        
         subprocess.Popen(f"{config.HIDDIFY_CONFIG_PATH}/update.sh",cwd=f"{config.HIDDIFY_CONFIG_PATH}",start_new_session=True)
         return render_template("result.html",
                             out_type="success",
@@ -117,15 +139,13 @@ class Actions(FlaskView):
 
 
 
+    def update_usage(self):
+        
+        
+        import json
 
-
-
-    # def register_routes(bp):
-    #     bp.add_url_rule("/reverselog/<logfile>", view_func=reverselog)
-    #     bp.add_url_rule("/apply_configs", view_func=apply_configs)
-    #     # bp.add_url_rule("/change", view_func=change)
-    #     bp.add_url_rule("/reinstall", view_func=reinstall)
-    #     bp.add_url_rule("/reset", view_func=reset)
-    #     bp.add_url_rule("/status", view_func=status)
-    #     bp.add_url_rule("/update", view_func=update)
-    #     bp.add_url_rule("/viewlogs", view_func=viewlogs)
\ No newline at end of file
+        return render_template("result.html",
+                            out_type="info",
+                            out_msg=f'<pre class="ltr">{json.dumps(hiddify.update_usage(),indent=2)}</pre>',
+                            log_path=None
+        )
