@@ -37,7 +37,7 @@ def make_proxy(proxy):
     domain = g.domain
     hconfigs=get_hconfigs()
     port=0
-    if l3 in ["tls","xtls"]:
+    if l3 in ["tls"]:
         port=443
     elif l3 =="http":
         port = 80
@@ -51,7 +51,7 @@ def make_proxy(proxy):
     direct_host=domain if is_cdn else g.direct_host
     
     base={
-        'name':name.replace(" ", "_"),#+f'_{l3}_s',
+        'name':name.replace(" ", "_"),
         'cdn':is_cdn,
         'mode':"CDN" if is_cdn else "direct",
         'l3': l3,
@@ -62,7 +62,8 @@ def make_proxy(proxy):
         'proto':proxy.proto,
         'transport':proxy.transport,
         'proxy_path':hconfig(ConfigEnum.proxy_path),
-        'alpn':"h2"
+        'alpn':"h2",
+        'extra_info':f'{domain}'
     }
 
     if base["proto"]=="trojan" and l3!="tls":
@@ -74,7 +75,7 @@ def make_proxy(proxy):
         return 
     
 
-    if "FAKE" in name:
+    if "Fake" in name:
         if not hconfig(ConfigEnum.domain_fronting_domain):
             return
         if l3=="http" and not hconfig(ConfigEnum.domain_fronting_http_enable):
@@ -111,7 +112,7 @@ def make_proxy(proxy):
         base["ssr-obfs"]= "tls1.2_ticket_auth"
         base["ssr-protocol"]= "auth_sha1_v4"
         base["fakedomain"]=hconfigs[ConfigEnum.ssr_fakedomain]
-        base["mode"]="faketls"
+        base["mode"]="FakeTLS"
         return base
     elif "faketls" in name:
         base['fakedomain']=hconfig(ConfigEnum.ssfaketls_fakedomain)
@@ -123,14 +124,16 @@ def make_proxy(proxy):
         return base
 
     if "XTLS" in name:
-        return {**base, 'transport': 'tcp', 'l3': 'xtls', 'alpn':'h2','flow':'xtls-rprx-direct'}
+        base['flow']='xtls-rprx-vision' if proxy.transport=='XTLSVision' else 'xtls-rprx-direct'
+        return {**base, 'transport': 'tcp', 'l3': 'xtls', 'alpn':'h2'}
     if "tcp" in name:
         base['transport']='tcp'
         base['path']=tcp_path[base["proto"]]
         return base   
-    if "WS" in name:
+    if proxy.transport in ["ws","WS"]:
         base['transport']='ws'
         base['path']=ws_path[base["proto"]]
+        base["host"]=domain
         return base
     if "grpc" in name:
         base['transport']='grpc'
@@ -142,35 +145,39 @@ def make_proxy(proxy):
         base['transport']= 'tcp'
         base['alpn']='http/1.1'
         return base
-    return "error!"
+    return {'name': name, 'error':True}
 
 
 def to_link(proxy):
-    if type(proxy) is str:return proxy
+    if 'error' in proxy:return proxy
+
+    name_link=proxy["name"]+"_"+proxy['extra_info']
     if proxy['proto']=='vmess':
         vmess_type= 'http' if proxy["transport"]=='tcp' else 'none'
-        return pbase64(f'vmess://{{"v":"2", "ps":"{proxy["name"]}", "add":"{proxy["server"]}", "port":"{proxy["port"]}", "id":"{proxy["uuid"]}", "aid":"0", "scy":"auto", "net":"{proxy["transport"]}", "type":"none", "host":"{proxy.get("host","")}", "path":"{proxy["path"] if "path" in proxy else ""}", "tls":"{proxy["l3"]}", "sni":"{proxy["sni"]}"}}')
+        return pbase64(f'vmess://{{"v":"2", "ps":"{name_link}", "add":"{proxy["server"]}", "port":"{proxy["port"]}", "id":"{proxy["uuid"]}", "aid":"0", "scy":"auto", "net":"{proxy["transport"]}", "type":"none", "host":"{proxy.get("host","")}", "path":"{proxy["path"] if "path" in proxy else ""}", "tls":"{proxy["l3"]}", "sni":"{proxy["sni"]}"}}')
     if proxy['proto']=="ssr":
         baseurl=f'ssr://proxy["encryption"]:{proxy["uuid"]}@{proxy["server"]}:{proxy["port"]}'
         return None
     if proxy['proto'] in ['ss','v2ray']:
         baseurl=f'ss://proxy["encryption"]:{proxy["uuid"]}@{proxy["server"]}:{proxy["port"]}'
         if proxy['mode']=='faketls':
-            return f'{baseurl}?plugin=obfs-local%3Bobfs%3Dtls%3Bobfs-host%3D{proxy["fakedomain"]}&amp;udp-over-tcp=true#{proxy["name"]}'
+            return f'{baseurl}?plugin=obfs-local%3Bobfs%3Dtls%3Bobfs-host%3D{proxy["fakedomain"]}&amp;udp-over-tcp=true#{name_link}'
         if proxy['mode']=='shadowtls':
-            return f'{baseurl}?plugin=shadow-tls%3Bpassword%3D{proxy["proxy_path"]}%3Bhost%3D{proxy["fakedomain"]}&amp;udp-over-tcp=true#{proxy["name"]}'
+            return f'{baseurl}?plugin=shadow-tls%3Bpassword%3D{proxy["proxy_path"]}%3Bhost%3D{proxy["fakedomain"]}&amp;udp-over-tcp=true#{name_link}'
         if proxy['proto']=='v2ray':
-            return f'{baseurl}?plugin=v2ray-plugin%3Bmode%3Dwebsocket%3Bpath%3D{proxy["path"]}%3Bhost%3D{domain}%3Btls&amp;udp-over-tcp=true#{proxy["name"]}'
+            return f'{baseurl}?plugin=v2ray-plugin%3Bmode%3Dwebsocket%3Bpath%3D{proxy["path"]}%3Bhost%3D{proxy["host"]}%3Btls&amp;udp-over-tcp=true#{name_link}'
     
-    infos=f'&alpn={proxy["alpn"]}&sni={proxy["sni"]}&type={proxy["transport"]}'
+    infos=f'&sni={proxy["sni"]}&type={proxy["transport"]}'
+    if proxy['alpn']!='h2':
+        infos+=f'&alpn={proxy["alpn"]}'
     infos+=f'&path={proxy["path"]}' if "path" in proxy else ""
-    infos+='&host={proxy["host"]}' if "host" in proxy else ""
+    infos+=f'&host={proxy["host"]}' if "host" in proxy else ""
     if "grpc"==proxy["transport"]:
         infos+=f'&serviceName={proxy["grpc_service_name"]}&mode={proxy["grpc_mode"]}'
     
-    infos+=f'#{proxy["name"]}'
+    infos+=f'#{name_link}'
     baseurl=f'{proxy["proto"]}://{proxy["uuid"]}@{proxy["server"]}:{proxy["port"]}'
-    if proxy['l3']=='xtls':
+    if 'xtls' == proxy['l3']:
         return f'{baseurl}?flow={proxy["flow"]}&security=xtls&type=tcp{infos}'
     if proxy['l3']=='http':
         return f'{baseurl}?security=none{infos}'
@@ -182,6 +189,7 @@ def to_clash_yml(proxy):
 
 def to_clash(proxy,meta_or_normal):
     if proxy['l3']=="kcp":return
+    if proxy.get('flow','')=="xtls-rprx-vision":return
     if meta_or_normal=="normal":
         if proxy['proto']=="vless":return
         if proxy['l3']=="xtls":return
@@ -208,7 +216,7 @@ def to_clash(proxy,meta_or_normal):
         if proxy["transport"]=="faketls":
             base["plugin"]= "obfs"
             base["plugin-opts"]={
-                "mode": tls,
+                "mode": 'tls',
                 "host": proxy["fakedomain"]
             }
         elif proxy["transport"]=="shadowtls":
@@ -220,6 +228,7 @@ def to_clash(proxy,meta_or_normal):
             
         elif proxy["proto"]=="v2ray":
             base["plugin"]= "v2ray-plugin"
+            base["type"]="ss"
             base["plugin-opts"]={
                 "mode": "websocket",
                 "tls": proxy["l3"]=="tls",
@@ -235,8 +244,8 @@ def to_clash(proxy,meta_or_normal):
         base["uuid"]= proxy["uuid"]
         base["servername"]= proxy["sni"]
         base["tls"]= proxy["l3"]=="tls"
-    if "proxy"=="XTLS":
-        base["flow"]= "xtls-rprx-direct"
+    if "xtls" == proxy['l3']:
+        base["flow"]= proxy['flow']
         base["flow-show"]= True
 
     if proxy["proto"]=="vmess":
