@@ -6,12 +6,13 @@ from hiddifypanel.models import User,Domain,BoolConfig,StrConfig,DomainType,Conf
 from hiddifypanel.panel.hiddify  import auth
 from . import link_maker
 from flask_classful import FlaskView,route
-
+import random
+from urllib.parse import urlparse
 class UserView(FlaskView):
 
     def index(self):
+        
         c=get_common_data(g.user_uuid)
-
         return render_template('home/index.html',**c)
         
 
@@ -31,9 +32,9 @@ class UserView(FlaskView):
         
         c=get_common_data(g.user_uuid)
         
-
-
-        resp= Response(render_template('clash_config.yml',mode=mode,meta_or_normal=meta_or_normal,**c,hash=hash(f'{c}')))
+        
+        hash_rnd=random.randint(0,1000000) #hash(f'{c}')
+        resp= Response(render_template('clash_config.yml',mode=mode,meta_or_normal=meta_or_normal,**c,hash=hash_rnd))
         resp.mimetype="text/plain"
         resp.headers['Subscription-Userinfo']=f"upload=0;download={c['usage_current_b']};total={c['usage_limit_b']};expire={c['expire_s']}"
         return resp
@@ -57,21 +58,22 @@ def do_base_64(str):
     return resp.decode()
     
 def get_common_data(user_uuid):
-    from urllib.parse import urlparse
+    
     
     o = urlparse(request.base_url)
     db_domain=Domain.query.filter(Domain.domain==o.hostname).first()
     domain=o.hostname
+    direct_host= domain
     is_cdn=False
     if db_domain and db_domain.mode==DomainType.cdn:
         direct_host=urllib.request.urlopen('https://v4.ident.me/').read().decode('utf8')
         is_cdn=True
     
-    direct_host= domain
+    
     # uuid_secret=str(uuid.UUID(user_secret))
     user=User.query.filter(User.uuid==f'{user_uuid}').first()
     if user is None:
-        raise ValidationError("Invalid User")
+        abort(401,"Invalid User")
     g.domain=domain
     g.direct_host=direct_host
     g.is_cdn=is_cdn
@@ -80,10 +82,11 @@ def get_common_data(user_uuid):
         'user':user,
         'domain':domain,
         'is_cdn':is_cdn,
-        'usage_limit_b':user.monthly_usage_limit_GB*1024*1024*1024,
-        'usage_current_b':user.current_usage_GB*1024*1024*1024,
-        'expire_s':(user.expiry_time-datetime.date(1970, 1, 1)).total_seconds(),
+        'usage_limit_b':int(user.usage_limit_GB*1024*1024*1024),
+        'usage_current_b':int(user.current_usage_GB*1024*1024*1024),
+        'expire_s':int((user.expiry_time-datetime.date(1970, 1, 1)).total_seconds()),
         'expire_days':(user.expiry_time-datetime.date.today()).days,
+        'reset_day':30-(datetime.date.today()-user.last_reset_time).days,
         'hconfigs':get_hconfigs(),
         'hdomains':get_hdomains(),
         'ConfigEnum':ConfigEnum,
